package and09.multiweatherapp

import android.os.Bundle
import com.google.android.material.bottomnavigation.BottomNavigationView
import androidx.appcompat.app.AppCompatActivity
import androidx.navigation.findNavController
import androidx.navigation.ui.AppBarConfiguration
import androidx.navigation.ui.setupActionBarWithNavController
import androidx.navigation.ui.setupWithNavController
import and09.multiweatherapp.databinding.ActivityMainBinding
import android.content.Context
import android.content.SharedPreferences
import android.location.Location
import android.location.LocationListener
import android.location.LocationManager
import android.util.Log
import androidx.preference.PreferenceManager

class MainActivity : AppCompatActivity() {
    var minTime = 5000L // in Millisekunden
    var minDistance = 5.0f // in Metern
    val locationListener = WeatherLocationListener()

    inner class WeatherLocationListener : LocationListener {
        override fun onLocationChanged(location: Location) {
            Log.d(javaClass.simpleName, "Empfangene Geodaten:\n$location")
            /*            val textview = findViewById<TextView>(R.id.textview_output)
                        textview.append("\nEmpfangene Geodaten:\n$location")*/
        }
    }

    private lateinit var binding: ActivityMainBinding

    fun startGPSListener() {
        val locationManager = getSystemService(Context.LOCATION_SERVICE) as LocationManager
        try {
            locationManager.requestLocationUpdates(
                "gps",
                minTime,
                minDistance,
                locationListener
            )
        } catch (ex: SecurityException) {
            Log.e(
                javaClass.simpleName,
                "Erforderliche Berechtigung $ex.toString() nicht erteilt"
            )
        }
    }

    fun stopGPSListener() {
        val locationManager = getSystemService(Context.LOCATION_SERVICE) as LocationManager
        locationManager.removeUpdates(locationListener)
    }

    val prefsChangedListener = object: SharedPreferences.OnSharedPreferenceChangeListener {
        override fun onSharedPreferenceChanged(prefs: SharedPreferences?, key: String?) {
            println("prefs changed, key: $key")
            if (key.equals("use_gps")) {
                    if (prefs!!.getBoolean("use_gps", false)) startGPSListener()
                    else stopGPSListener()
        }
        }

    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        val prefs = PreferenceManager.getDefaultSharedPreferences(applicationContext)
        prefs.registerOnSharedPreferenceChangeListener(prefsChangedListener)

        if (prefs.getBoolean("use_gps", false)) startGPSListener()

        binding = ActivityMainBinding.inflate(layoutInflater)
        setContentView(binding.root)

        val navView: BottomNavigationView = binding.navView

        val navController = findNavController(R.id.nav_host_fragment_activity_main)
        // Passing each menu ID as a set of Ids because each
        // menu should be considered as top level destinations.
        val appBarConfiguration = AppBarConfiguration(
            setOf(
                R.id.navigation_home, R.id.navigation_dashboard, R.id.navigation_notifications
            )
        )
        setupActionBarWithNavController(navController, appBarConfiguration)
        navView.setupWithNavController(navController)
    }
}